@@ -1,7 +1,7 @@
 #!/bin/bash -ex
 
 # Clean environment, to avoid https://github.com/django-mptt/django-mptt/issues/513
-python ./setup.py clean
+python3 ./setup.py clean
 rm -rf ./*.egg-info
 
-python setup.py sdist bdist_wheel register upload
+python3 setup.py sdist bdist_wheel
