@@ -1,7 +1,11 @@
-__version__ = "0.11.0"
+import django
+
+
+__version__ = "0.13.2"
 VERSION = tuple(__version__.split("."))
 
-default_app_config = "mptt.apps.MpttConfig"
+if django.VERSION < (3, 2):  # pragma: no cover
+    default_app_config = "mptt.apps.MpttConfig"
 
 
 def register(*args, **kwargs):
@@ -10,6 +14,7 @@ def register(*args, **kwargs):
     This is equivalent to just subclassing MPTTModel, but works for an already-created model.
     """
     from mptt.models import MPTTModelBase
+
     return MPTTModelBase.register(*args, **kwargs)
 
 
