@@ -2,11 +2,11 @@
 Model fields for working with trees.
 """
 from django.db import models
-from django.conf import settings
+
 from mptt.forms import TreeNodeChoiceField, TreeNodeMultipleChoiceField
 
 
-__all__ = ('TreeForeignKey', 'TreeOneToOneField', 'TreeManyToManyField')
+__all__ = ("TreeForeignKey", "TreeOneToOneField", "TreeManyToManyField")
 
 
 class TreeForeignKey(models.ForeignKey):
@@ -22,17 +22,17 @@ class TreeForeignKey(models.ForeignKey):
         """
         Use MPTT's ``TreeNodeChoiceField``
         """
-        kwargs.setdefault('form_class', TreeNodeChoiceField)
-        return super(TreeForeignKey, self).formfield(**kwargs)
+        kwargs.setdefault("form_class", TreeNodeChoiceField)
+        return super().formfield(**kwargs)
 
 
 class TreeOneToOneField(models.OneToOneField):
     def formfield(self, **kwargs):
-        kwargs.setdefault('form_class', TreeNodeChoiceField)
-        return super(TreeOneToOneField, self).formfield(**kwargs)
+        kwargs.setdefault("form_class", TreeNodeChoiceField)
+        return super().formfield(**kwargs)
 
 
 class TreeManyToManyField(models.ManyToManyField):
     def formfield(self, **kwargs):
-        kwargs.setdefault('form_class', TreeNodeMultipleChoiceField)
-        return super(TreeManyToManyField, self).formfield(**kwargs)
+        kwargs.setdefault("form_class", TreeNodeMultipleChoiceField)
+        return super().formfield(**kwargs)
